@@ -510,11 +510,11 @@ impl BuildOptions {
             }),
         )?;
 
-        if !bridge.is_bin() && module_name.contains('-') {
+        if !bridge.is_bin() && project_layout.extension_name.contains('-') {
             bail!(
                 "The module name must not contain a minus `-` \
                  (Make sure you have set an appropriate [lib] name or \
-                 [package.metadata.maturin] name in your Cargo.toml)"
+                 [tool.maturin] module-name in your pyproject.toml)"
             );
         }
 
@@ -1089,15 +1089,10 @@ fn find_interpreter_in_sysconfig(
         let ver_minor = ver_minor.parse::<usize>().with_context(|| {
             format!("Invalid python interpreter minor version '{ver_minor}', expect a digit")
         })?;
-        let sysconfig = InterpreterConfig::lookup(
-            target.target_os(),
-            target.target_arch(),
-            python_impl,
-            (ver_major, ver_minor),
-        )
-        .with_context(|| {
-            format!("Failed to find a {python_impl} {ver_major}.{ver_minor} interpreter")
-        })?;
+        let sysconfig = InterpreterConfig::lookup(target, python_impl, (ver_major, ver_minor))
+            .with_context(|| {
+                format!("Failed to find a {python_impl} {ver_major}.{ver_minor} interpreter")
+            })?;
         debug!(
             "Found {} {}.{} in bundled sysconfig",
             sysconfig.interpreter_kind, sysconfig.major, sysconfig.minor,
