@@ -151,7 +151,7 @@ impl GenerateCI {
                     | BridgeModel::Cffi
                     | BridgeModel::UniFfi
             );
-        let gen_cmd = std::env::args()
+        let mut gen_cmd = std::env::args()
             .enumerate()
             .map(|(i, arg)| {
                 if i == 0 {
@@ -162,12 +162,17 @@ impl GenerateCI {
             })
             .collect::<Vec<String>>()
             .join(" ");
+        if gen_cmd.starts_with("maturin new") || gen_cmd.starts_with("maturin init") {
+            gen_cmd = format!("{} generate-ci github", env!("CARGO_PKG_NAME"));
+        }
         let mut conf = format!(
             "# This file is autogenerated by maturin v{version}
 # To update, run
 #
 #    {gen_cmd}
 #
+name: CI
+
 on:
   push:
     branches:
@@ -509,6 +514,8 @@ mod tests {
             .collect::<Vec<_>>()
             .join("\n");
         let expected = indoc! {r#"
+            name: CI
+
             on:
               push:
                 branches:
@@ -636,6 +643,8 @@ mod tests {
             .collect::<Vec<_>>()
             .join("\n");
         let expected = indoc! {r#"
+            name: CI
+
             on:
               push:
                 branches:
@@ -757,6 +766,8 @@ mod tests {
             .collect::<Vec<_>>()
             .join("\n");
         let expected = indoc! {r#"
+            name: CI
+
             on:
               push:
                 branches:
@@ -923,6 +934,8 @@ mod tests {
             .collect::<Vec<_>>()
             .join("\n");
         let expected = indoc! {r#"
+            name: CI
+
             on:
               push:
                 branches:
